import AntModal from '@/components/pt/dialog/AntModal'
import {
  getSysReservationConfig,
  addSysReservationConfig,
  updateSysReservationConfig,
  batchAddSysReservationConfig,
  createSysReservationConfigTimeDuration
} from '@/api/system/sysReservationConfig'
import { getAllNotDelSysWharf } from '@/api/system/sysWharf'
import moment from 'moment'

export default {
  name: 'CreateForm',
  props: {
    statusOptions: {
      type: Array,
      required: true
    }
  },
  components: {
    AntModal
  },
  data () {
    return {
      open: false,
      closeDialog: true,
      spinning: false,
      delayTime: 100,
      labelCol: { span: 4 },
      wrapperCol: { span: 14 },
      loading: false,
      disabled: false,
      total: 0,
      id: undefined,
      formTitle: '预约配置',
      // 表单参数
      form: {
        enableWharf: []
      },
      configForm: {
        startTime: '',
        endTime: '',
        duration: null
      },
      batchForm: {
        dateRange: [],
        enableWharf: []
      },
      rules: {
        reservationDate: [{ required: true, message: '预约日期不能为空', trigger: 'blur' }],
        reservationStartTime: [{ required: true, message: '预约开始时段不能为空', trigger: 'blur' }],
        reservationEndTime: [{ required: true, message: '预约结束时段不能为空', trigger: 'blur' }],
        enableNum: [{ required: true, message: '可预约人数不能为空', trigger: 'blur' }],
        enableWharf: [{ required: true, message: '可预约码头不能为空', trigger: 'blur' }]
      },
      batchAddRules: {
        dateRange: [{ required: true, message: '预约日期不能为空', trigger: 'blur' }],
        duration: [{ required: true, message: '班次时长不能为空', trigger: 'blur' }],
        enableNum: [{ required: true, message: '可预约人数不能为空', trigger: 'blur' }],
        enableWharf: [{ required: true, message: '可预约码头不能为空', trigger: 'blur' }]
      },
      wharfList: [],
      timeDurations: [],
      columns: [
        {
          title: '开始时段',
          dataIndex: 'startTime',
          key: 'startTime',
          width: '20%'
        },
        {
          title: '结束时段',
          dataIndex: 'endTime',
          key: 'endTime',
          width: '20%'
        },
        {
          title: '可预约人数',
          dataIndex: 'enableNum',
          key: 'enableNum',
          scopedSlots: { customRender: 'enableNumSlot' },
          align: 'center'
        }
      ]
    }
  },
  filters: {},
  created () {
    this.getWharfList()
    console.log(this.statusOptions)
    this.getConfigKey('sys.route.start').then(response => {
      this.configForm.startTime = moment(new Date()).format('YYYY-MM-DD') + ' ' + response.data + ':00'
    })
    this.getConfigKey('sys.route.end').then(response => {
      this.configForm.endTime = moment(new Date()).format('YYYY-MM-DD') + ' ' + response.data + ':00'
    })
  },
  computed: {
  },
  watch: {},
  mounted () {},
  methods: {
    setEnableNum () {
      this.timeDurations.forEach(item => {
        item['enableNum'] = this.batchForm.enableNum
      })
    },
    createTimeDurations () {
      if (!this.batchForm.duration) {
        this.$message.error('请输入班次时长！')
        return false
      }
      this.timeDurations = []
      const params = {
        startTime: moment(this.configForm.startTime).format('HH:mm'),
        endTime: moment(this.configForm.endTime).format('HH:mm'),
        duration: this.batchForm.duration
      }
      createSysReservationConfigTimeDuration(params).then(response => {
        this.timeDurations = response.data
      })
    },
    getWharfList () {
      this.wharfList = []
      getAllNotDelSysWharf().then(response => {
        this.wharfList = response.data
        this.batchForm.enableWharf = this.wharfList.map(item => item.id)
      })
    },
    onClose () {
      this.open = false
      this.reset()
      this.$emit('close')
    },
    // 取消按钮
    cancel () {
      this.open = false
      this.reset()
      this.$emit('close')
    },
    // 表单重置
    reset () {
      this.form = {
        id: undefined,
        reservationDate: undefined,

        reservationStartTime: undefined,

        reservationEndTime: undefined,

        enableNum: undefined,

        status: '0'

      }
    },
    /** 新增按钮操作 */
    handleAdd () {
      this.reset()
      this.open = true
      this.formTitle = '预约配置'
    },
    /** 修改按钮操作 */
    handleUpdate (row) {
      this.reset()
      this.open = true
      this.spinning = !this.spinning
      const sysReservationConfigId = row.id
      getSysReservationConfig(sysReservationConfigId).then(response => {
        this.form = response.data
        this.form.reservationStartTime = this.form.reservationDate + ' ' + this.form.reservationStartTime + ':00'
        this.form.reservationEndTime = this.form.reservationDate + ' ' + this.form.reservationEndTime + ':00'
        this.form.enableWharf = this.form.enableWharf.split(',')
        this.formTitle = '修改预约配置'
        this.spinning = !this.spinning
      })
    },
    batchSave: function (closeDialog, status) {
      this.closeDialog = closeDialog
      this.disabled = true
      this.$refs.batchForm.validate(valid => {
        if (valid) {
          const saveForm = {
            startDate: this.batchForm.dateRange[0],
            endDate: this.batchForm.dateRange[1],
            duration: this.batchForm.duration,
            enableNum: this.batchForm.enableNum,
            enableWharf: this.batchForm.enableWharf.join(','),
            status: status,
            sysReservationConfigTimeDurationReqList: this.timeDurations
          }
          batchAddSysReservationConfig(saveForm).then(response => {
            this.$message.success('配置成功', 3)
            this.open = false
            this.$emit('ok')
            this.$emit('close')
            this.disabled = false
          })
        } else {
          this.disabled = false
          return false
        }
      })
    },
    /** 提交按钮 */
    submitForm: function (closeDialog) {
      this.closeDialog = closeDialog
      this.disabled = true
      this.$refs.form.validate(valid => {
        if (valid) {
          const saveForm = JSON.parse(JSON.stringify(this.form))
          if (this.form.id !== undefined) {
            const params = {
              id: this.form.id,
              status: this.form.status,
              enableWharf: this.form.enableWharf.join(','),
              enableNum: this.form.enableNum
            }
            updateSysReservationConfig(params).then(response => {
              this.$message.success('更新成功', 3)
              this.open = false
              this.$emit('ok')
              this.$emit('close')
              this.disabled = false
            })
          } else {
            addSysReservationConfig(saveForm).then(response => {
              this.$message.success('新增成功', 3)
              this.open = false
              this.$emit('ok')
              this.$emit('close')
              this.disabled = false
            })
          }
        } else {
          this.disabled = false
          return false
        }
      })
    },
    back () {
      const index = '/system/sysreservationconfig/index'
      this.$router.push(index)
    }

  }
}
